==> kdeadmin-1.91.tar.bz2: kdeadmin-1.91/ksysctrl/ksysctrl/deventry.cpp <==
/*
 *  This file is part of the KDE System Control Tool,
 *  Copyright (C)1999 Thorsten Westheider <twesthei@physik.uni-bielefeld.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 ****************************************************************************/

#include "deventry.h"


DeviceEntry::DeviceEntry(QListViewItem *parent, Device *pcidev) : QListViewItem(parent),
					                          _device(pcidev),
								  _conflict(false)
{
  QString  devname   = _device->deviceName();
  QString  classname = _device->deviceClassName();
  
  if (!classname.isEmpty()) devname += " ("+classname+")";
  
  setText(0, devname);
  
  _baseclass = _device->deviceBaseClass();
}


DeviceEntry::DeviceEntry(QListView *parent, Device::baseclass bclass,
                         const char *classname) : QListViewItem(parent, classname),
			 			  _device(0L),
						  _baseclass(bclass),
						  _conflict(false)
{
  setText(0, classname);  
}

==> kdeadmin-2.1.1.tar.bz2: kdeadmin-2.1.1/ksysctrl/ksysctrl/deventry.cpp <==
/*
 *  This file is part of the KDE System Control Tool,
 *  Copyright (C)1999 Thorsten Westheider <twesthei@physik.uni-bielefeld.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 ****************************************************************************/

#include "deventry.h"


DeviceEntry::DeviceEntry(QListViewItem *parent, Device *pcidev) : QListViewItem(parent),
					                          _device(pcidev),
								  _conflict(false)
{
  QString  devname   = _device->deviceName();
  QString  classname = _device->deviceClassName();
  
  if (!classname.isEmpty()) devname += " ("+classname+")";
  
  setText(0, devname);
  
  _baseclass = _device->deviceBaseClass();
}


DeviceEntry::DeviceEntry(QListView *parent, Device::baseclass bclass,
                         const QString & classname) : QListViewItem(parent, classname),
			 			  _device(0L),
						  _baseclass(bclass),
						  _conflict(false)
{
  setText(0, classname);  
}
